summaryrefslogtreecommitdiff
path: root/searx/enginelib
diff options
context:
space:
mode:
authorMarkus Heiser <markus.heiser@darmarit.de>2023-08-08 08:06:22 +0200
committerMarkus Heiser <markus.heiser@darmarIT.de>2023-08-08 08:15:53 +0200
commitbcaaae699f01d44fa83dd8c251d9b30e5325d5e9 (patch)
tree5f4a81d6ef5860c0d34f0885912d659bcbae25f0 /searx/enginelib
parenta2108432f79581c8b87ccf456d7f866afa27a50b (diff)
downloadsearxng-bcaaae699f01d44fa83dd8c251d9b30e5325d5e9.tar.gz
searxng-bcaaae699f01d44fa83dd8c251d9b30e5325d5e9.zip
[doc] fix some minor typos in the doc-strings of class EngineTraits
Signed-off-by: Markus Heiser <markus.heiser@darmarit.de>
Diffstat (limited to 'searx/enginelib')
-rw-r--r--searx/enginelib/traits.py18
1 files changed, 10 insertions, 8 deletions
diff --git a/searx/enginelib/traits.py b/searx/enginelib/traits.py
index 8a7356ce2..6402fde22 100644
--- a/searx/enginelib/traits.py
+++ b/searx/enginelib/traits.py
@@ -95,8 +95,8 @@ class EngineTraits:
:param default: engine's default language
The *best fits* rules are implemented in
- :py:obj:`locales.get_engine_locale`. Except for the special value ``all``
- which is determined from :py:obj`EngineTraits.all_language`.
+ :py:obj:`searx.locales.get_engine_locale`. Except for the special value ``all``
+ which is determined from :py:obj:`EngineTraits.all_locale`.
"""
if searxng_locale == 'all' and self.all_locale is not None:
return self.all_locale
@@ -111,18 +111,20 @@ class EngineTraits:
:param default: engine's default region
The *best fits* rules are implemented in
- :py:obj:`locales.get_engine_locale`. Except for the special value ``all``
- which is determined from :py:obj`EngineTraits.all_language`.
+ :py:obj:`searx.locales.get_engine_locale`. Except for the special value ``all``
+ which is determined from :py:obj:`EngineTraits.all_locale`.
"""
if searxng_locale == 'all' and self.all_locale is not None:
return self.all_locale
return locales.get_engine_locale(searxng_locale, self.regions, default=default)
def is_locale_supported(self, searxng_locale: str) -> bool:
- """A *locale* (SearXNG's internal representation) is considered to be supported
- by the engine if the *region* or the *language* is supported by the
- engine. For verification the functions :py:func:`self.get_region` and
- :py:func:`self.get_region` are used.
+ """A *locale* (SearXNG's internal representation) is considered to be
+ supported by the engine if the *region* or the *language* is supported
+ by the engine.
+
+ For verification the functions :py:func:`EngineTraits.get_region` and
+ :py:func:`EngineTraits.get_language` are used.
"""
if self.data_type == 'traits_v1':
return bool(self.get_region(searxng_locale) or self.get_language(searxng_locale))